Registration Form

Jump to content

- Step 1 Your Account
- Step 2 Confirmation

Sign Up with Facebook Sign Up with Twitter

## Join Our Community

### Join Our Community - Register now for FREE

- Subscribe to the following mailing lists

- ### Grasscity.com Forum Newsletter

- ### I'm interested in

  ### Grasscity.com Discount Coupons New Products News on Medical Marijuana in General News on Medical Marijuana Dispensaries 3rd Party Partner MMJ Mailings Forum and Community related news News on Hydrophonics and Cannabis Growing News on Cannabis Strains and Cannabis Seeds MMJ Edibles Vaporizers / E-Cigs Concentrates, Dabbing and BHO Cannabidiol (CBD)

Anti-spam: complete the task

- Receive messages from Forum Staff
- I've read and agree to the Terms of Use and Privacy Policy <!-- isHtml:1 --><p style="text-align: center;"><strong><span style="color: rgb(0, 100, 0);">END USER LICENSE AGREEMENT – GRASSCITY.COM</span></strong></p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 1 General</strong></span></p><p><br /> </p><p style="margin-left: 40px;">This End User License Agreement (“EULA”) applies to the use of the forum of Grasscity Forums (“Community”) through the website <a class='bbc_url' href='http://www.grasscity.com'>www.grasscity.com</a>, <a class='bbc_url' href='http://forum.grasscity.com'>forum.grasscity.com</a> and any underlying or related webpage (“Website”) and or the mobile application of Grasscity Forums (“Grasscity Community App”). To be able to make full use of the Community you have to agree to this EULA. We advise you to read this EULA carefully so you are aware of your rights and responsibilities when you use the Community. You can download and print this EULA url needs to be inserted .</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">SJV 2 B.V., (“Grasscity Forums”) is a company with limited liability established and existing under the laws of The Netherlands, having its registered office in 1042 AC Amsterdam, the Netherlands, at Gyroscoopweg 64, registered with the Chamber of Commerce under number 55042503.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">By using the Community and/or accepting this EULA you acknowledge and guarantee that you have reached the age of 18 years. The Community is intended solely for users who are 18 years of age or older, and any registration, use or access to the Community by anyone under 18 is unauthorized, unlicensed, and in violation of this EULA. Grasscity Forums may terminate your account, delete any content or information that you have posted on the Community and/or prohibit you from using or accessing the Community (or any portion, aspect or feature of the Community) for any reason, at any time in its sole discretion, with or without notice, including without limitation if it believes that you are under 18.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums is at all times authorised to amend or supplement this EULA. The most up-to-date EULA can always be found in the Community. The amended or supplemented EULA will be brought to your attention during your use of the Community or in your personal environment in the Community (“Account”). If you continue to use the Community after the EULA has been amended or supplemented, by such action you irrevocably accept the amended or supplemented EULA. If you do not agree to the amended or supplemented EULA, your only option is to cease using the Community and to terminate your Account.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 2 Account</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">In order to make full use of the Community, including posting content to the forum, you are required to create an Account in the way as described on the Website and/or Application. It is not permitted to create an Account using the name of another person or company. During registration, you must provide a user name, e-mail and password (“Login Details”) with which you can gain access to your Account.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You are responsible for maintaining secrecy with regard to the Login Details for your Account. As soon as you know or have reason to suspect that your Login Details have come into the hands of unauthorized persons, you must inform Grasscity Forums of this immediately, without prejudice to your own obligation to immediately take effective action, such as modifying your Login Details. You therefore accept and acknowledge that you are at all times responsible and liable for the use of the Community by third parties via your Account.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 3 Use of the Community</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">You accept that the Website, Application and Community contains only the functionalities and information that you find at the moment of use (“as is” and “as available”). Grasscity Forums may at all times (i) make functional, procedural or technical changes or improvements to the Community and (ii) (temporarily or permanently) take out of service, restrict the use of or terminate the Community. If you do not agree with the changes and/or improvements made, your only option is to cease using the Community and to terminate your Account.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You acknowledge and agree that the personal information and all information – including but not limited to data, text, photos, images, videos and other (visual)material – you make available trough the Community (“Material”) can be seen and/or used by other registered persons who use the Community (“User”).</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Each and every use of the Community is for your own risk and responsibility. Grasscity Forums has no knowledge of and/or interference with the Material which is made available by Users through use of the Community and therefore does not accept any responsibility and/or liability whatsoever. You acknowledge that Grasscity Forums cannot enforce compliance with the EULA or any other applicable law, rule or regulation by other Users.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You are solely responsible and liable for Material provided. You may delete your own Material within seven (7) days of posting the Material. If you wish to delete Material after seven (7) days, you can contact Grasscity Forums via the <a class='bbc_url' href='http://forum.grasscity.com/contactus'>"Contact Us"</a> page. In the event the Material includes photo’s in the Photo Gallery, you may delete the photos at any time.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You are not permitted to:</p><p style="margin-left: 40px;">a. resell, distribute or in any other way commercially use the Community;</p><p style="margin-left: 40px;">b. <strong>use the Community and/or make Material available in a way that is contrary to the purpose and morals of the Community, this includes – but is not limited to – any reference to the products of Grasscity Forums in another context than medicinal use of such products. Any reference to recreational use of such products is strictly prohibited;</strong></p><p style="margin-left: 40px;">c. use the Community and/or make Material available in a way that is discriminating regarding race, religion, gender, culture or heritage or which is otherwise offensive, hurtful, or inappropriate, to the sole discretion of Grasscity Forums;</p><p style="margin-left: 40px;">d. use the Community and/or make Material available in a way that calls for violence against and/or harassment of others;</p><p style="margin-left: 40px;">e. use the Community and/or make Material available in a way that is false and/or misleading, including – but not limited to – the adoption of a false identity and/or making the incorrect suggestion that you are in any way commercially connected with Grasscity Forums;</p><p style="margin-left: 40px;">f. make Material available which contains viruses, Trojan horses, worms, bots or other software that can damage, disable or delete the Community or makes it inaccessible, or which alters the Material;</p><p style="margin-left: 40px;">g. reproduce, publish or sell the Material obtained through the Community;</p><p style="margin-left: 40px;">h. use contact information which is provided by Users for any commercial, non-commercial or charitable communication as well as any other unsolicited communication other than the intended purposes of the Community;</p><p style="margin-left: 40px;">i. make Material available that contains (unsolicited) advertisement, promotional materials, junk mail, spam, chain letters, pyramid schemes, any form of lottery or gambling, or any other form of solicitation;</p><p style="margin-left: 40px;">j. violate the EULA, the privacy policy of Grasscity Forums available at (“Privacy Policy”) or any applicable laws and/or regulations;</p><p style="margin-left: 40px;">k. infringe on the rights of Grasscity Forums and/or third parties, including – but not limited to – intellectual property rights and rights that relate to the protection of privacy;</p><p style="margin-left: 40px;">l. harm the interests and reputation of Grasscity Forums;</p><p style="margin-left: 40px;">m. engage third parties to perform any of the above mentioned acts.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums reserves the right to modify, refuse or delete Material or to restrict the use of or terminate an Account if there are grounds to do so according to Grasscity Forums, without becoming liable to pay any compensation to you.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">If you are of the opinion that certain Material infringes your rights and/or the rights of other Users or a third party you should notify Grasscity Forums immediately by way of article 8.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 4 Intellectual Property Rights</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">The intellectual property rights and related rights such as copyright, trademark rights, patent rights, design rights, trade name rights, database rights and neighboring rights, as well as rights to know-how and sui generis intellectual property rights (“Intellectual Property Rights”) in relation to the Community, including the Intellectual Property Rights with respect to the Website, Application and Community – excluding the Material provided by you – and all information such as but not limited to data, text, photos, images, videos and other (visual)material are held by Grasscity Forums or its licensors.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Under the conditions set out in these EULA, Grasscity Forums grants you a limited, personal, revocable, non-exclusive, non-sublicensable and non-transferable right to access and use the Community insofar as is necessary for the non-commercial use of the Community.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">All Intellectual Property Rights in relation to Material will remain with the User who made the Material available through the Community. You acknowledge and accept that by making the Material available through the Community, you automatically and free of charge grant Grasscity Forums an unlimited, worldwide, irrevocable, sublicensable and transferable right to reproduce the Material and make the Material available, insofar as is necessary for the provision and promotion of the Community. You will, for as far as possible in accordance with the law, renounce all moral rights as mentioned in article 25 of the Dutch Copyright Act.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You guarantee that there are no (Intellectual Property) Rights of third parties which preclude making the Material available through the Community and/or providing the license.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Nothing in these EULA is intended to transfer any Intellectual Property Rights to any User. You shall refrain from any act that infringes the Intellectual Property Rights of Grasscity Forums, including – but not limited to – the registration of domain names, trademarks or Google Adwords that are identical or similar to any object to which Grasscity Forums holds Intellectual Property Rights, as well as the reproduction, modification, reverse engineering or publishing the Community, including the Material, for other purposes than those listed in the EULA.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 5 Privacy </strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">By creating the Account and by using the Community, you will provide personal data to Grasscity Forums. This personal data will be processed in accordance with the Privacy Policy of Grasscity Forums and the applicable laws and regulations link needs to be inserted here</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 6 Indemnities and warranties</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">You are liable for and indemnify Grasscity Forums completely against any damages and costs which Grasscity Forums suffers or makes as a result of (a claim of a third party resulting from) (i) an attributable breach of the EULA by you (ii) any use you make of the Community, or (iii) an unlawful act. You will reimburse all costs and damages that in any way relate to such a claim.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">You guarantee that you are entitled to use the Community, that you shall act in accordance with the EULA and that all Material posted on the Community is correct, complete, lawful and up-to-date.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 7 Liability</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">Grasscity Forums accepts no liability for damages that result from providing the Community, an unlawful act, or any other cause to the extent that is permitted under mandatory law.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">If Grasscity Forums is liable for damages arising from any cause whatsoever, this liability is at any time limited to the direct damages up to an absolute maximum of EUR 100,- per event (a sequence of events will be regarded as one event).</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Direct damage is understood to mean exclusively:</p><p style="margin-left: 40px;">a. damage to property;</p><p style="margin-left: 40px;">b. reasonable costs incurred to prevent or limit direct damages that could be expected from the event on which is the liability is based;</p><p style="margin-left: 40px;">c. reasonable costs incurrent in determining the cause of the damage.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Any liability of Grasscity Forums for damage other than direct damage (“indirect damages”), including – but not limited to – consequential damages, loss and/or damage of data, loss of profits and lost sales, loss of savings, reduced goodwill, damage by business interruption and damage as a result of claims from third parties is excluded.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">The limitations and exclusions of liability mentioned in the preceding paragraphs of this article will lapse if and in so far as the damage is the result of intentional or willful recklessness on the part of Grasscity Forums or its managers (“own actions”).</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">No right to damages shall exist unless you notify Grasscity Forums in writing of the damage promptly after it has arisen. Any claim for damages against Grasscity Forums shall become extinguished by the mere lapse of one (1) month after the claim has come into being.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 8 Notification of unlawful Content</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">Grasscity Forums is not liable for any damages in connection with the (illegal) use of the Community by you or any other User. Grasscity Forums will only, under the conditions as set out in this Article, be obliged to remove or block access to Material that is manifestly unlawful or to stop manifestly unlawful behavior after receiving a notification that is sufficiently precise and adequately substantiated.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums has established the procedure described below, by which any alleged illegal Material available through the Community can be reported to Grasscity Forums. This can be done via the website by clicking the "Report" button that is available on all threads and all posts. Please read <a class='bbc_url' href='http://forum.grasscity.com/general-forum-feedback/523231-how-report-things.html'>here</a> full instructions how to report unwanted behavior on the forums</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">If the notification is sufficiently precise and adequately substantiated and the Material is manifestly unlawful, Grasscity Forums will remove or block access to such Material. Grasscity Forums reserves the right to not grant a request to remove or block access to the Material or to stop an activity in case it has reasonable grounds to doubt the accuracy of the notification or in case a balancing of interest requires this. In such a situation Grasscity Forums can require a court order from a competent court in The Netherlands, to demonstrate that the material or the activity is manifestly unlawful.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums will not be a party in a dispute between the person making the report and any third party arising out of or in connection with a notification.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">The person making the notification indemnifies Grasscity Forums against all claims of third parties in relation to the blocking or removal of Material or the stopping of activities. The indemnification includes all damages and costs Grasscity Forums suffers, could suffer or which Grasscity Forums must incur in relation to such a claim, including but not limited to the compensation of legal assistance.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums respects and protects the privacy of those who provide notifications. All personal data that it receives as part of a notification will always be processed in accordance with the Dutch Data Protection Act and the Privacy Policy and will only be used to process the notification.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 9 Termination</strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">You are at any moment entitled to discontinue the use of the Community and to terminate your Account for convenience.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">If there are grounds to do so, without any further notification being required and without becoming liable to pay compensation, Grasscity Forums reserves the right to terminate your Account (temporarily or permanently) or to delete Material, specifically in – but not limited to – cases in which you, in Grasscity Forums’s opinion, have breached any of the provisions in these EULA.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">After termination of the Account, the Account shall be made inaccessible by Grasscity Forums. Any Material you have mad available in the Community shall remain available. Grasscity Forums shall not and is under no circumstance required to delete the Material and/or make the Material inaccessible.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">After termination of the Account, Grasscity Forums shall anonymize the Material, meaning that your posts shall refer to ‘Guest’ and no longer to your profile name.</p><p style="text-align:center;"> </p><p><span style="color: rgb(0, 100, 0);"><strong>Article 10 Miscellaneous </strong></span></p><p style="text-align:center;"><br /> </p><p style="margin-left: 40px;">The EULA and the use of the Community is subject to Dutch law. The applicability of the Vienna Sales Convention 1980 is expressly excluded.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">To the extent that national or international rules of law do not prescribe mandatory conditions to the contrary, any and all disputes arising from or related to the Community or the EULA will be brought before the competent court in Amsterdam.</p><p style="text-align:center;"> </p><p style="margin-left: 40px;">Grasscity Forums may transfer rights and obligations arising from these EULA to third parties and will notify you thereof. If you do not accept the transfer of rights and obligations you may discontinue the use of the Community and terminate your Account.</p><p style="margin-left: 40px;">If at any time any provision of this EULA is or becomes illegal, void or invalid for any reason whatsoever, such invalidity shall not affect the validity of the remainder of the EULA and such invalid provision shall be replaced by such other provision which, being valid in all respects, shall have effect as close as possible to that of such replaced one.</p><p style="text-align:center;"> </p><p style="text-align: right;">Last updated on 05 July 2013 , 15:32 Amsterdam, The Netherlands</p>

Already a member? Sign In

### Sign In

- Use Facebook
- Use Twitter

- Need an account? Register now!
- Username
- Password
  I've forgotten my password
- Remember me
  This is not recommended for shared computers
- Sign in anonymously
  Don't add me to the active users list
- Privacy Policy

### Network

- Grasscity Shop
- Grasscity Community
- Grasscity Magazine
- 420 Network

### Community

- Forums
- Gallery
- Blogs
- Contests

### Help

- Forum FAQ
- End User License Agreement
- Privacy Policy
- Contact Us

### Find Us On

- iPhone
  App
- Android
  App

© Copyright 1999 - 2015 420Network BV | All rights reserved